BrazilState class

One state, paired with the artwork for it.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
State name in Portuguese, for example São Paulo.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uf String
Two letter UF code, upper case, for example SP.
final

Methods

flag(FlagStyle style) FlagArtwork
This state's flag in style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited